Crate dua

Crate dua 

Public library API for dua core traversal and aggregation functionality.

This crate powers the dua binary and can also be used as a library.

Modules

snapshot
Reading and writing dua traversal snapshots. Streaming codec for dua traversal snapshots.
traverse
Filesystem traversal, in-memory tree representation, and traversal events.

Structs

Config
Runtime configuration used by interactive and CLI components.
IgnorePatterns
Gitignore-style patterns, read from files, which exclude entries from a traversal.
KeyBinding
One key and its optional modifiers.
KeyBindings
One or more keys that invoke an interactive action.
KeysConfig
Keyboard interaction settings.
TraversalOptions
Platform-specific filesystem metadata requested during traversal.
WalkOptions
Configures a filesystem walk, including output and formatting options.
WalkResult
Information we gather during a filesystem walk

Enums

ByteFormat
Specifies a way to format bytes

Functions

aggregate
Aggregate the given paths and write information about them to out in a human-readable format. If compute_total is set, it will write an additional line with the total size across all given paths. If sort_by_size_in_bytes is set, we will sort all sizes (ascending) before outputting them.
aggregate_replay
Render the top-level entries of a verified snapshot replay as an aggregate listing.
aggregate_snapshot
Render the top-level entries of a verified traversal snapshot as an aggregate listing.
aggregate_tree
Traverse paths and write an indented tree of their disk usage to out, descending up to max_depth levels below each given root.
aggregate_tree_from_replay
Replay a verified snapshot as an indented aggregate tree, retaining only displayed levels.
aggregate_tree_from_traversal
Write an already completed traversal as an indented aggregate tree.
canonicalize_ignore_dirs
Canonicalize user-provided ignore directory paths.
diff_snapshots
Compare two verified traversal snapshots without materializing either tree.
stacks
Traverse paths and write the tree to out as folded stacks, one entry per line, ready to pipe into flame-graph tools like inferno.
stacks_from_replay
Replay a verified snapshot as folded stacks while retaining only the current path.
stacks_from_traversal
Write an already completed traversal as folded stacks.