Module snapshot

Module snapshot 

Reading and writing dua traversal snapshots. Streaming codec for dua traversal snapshots.

Structs

Replay
A checksum-verified, seekable snapshot that can replay entries without materializing the tree.
Snapshot
A verified traversal snapshot and its input roots in their original order.

Functions

read
Read and fully verify a version-1 snapshot before returning its traversal.
write
Write traversal as a deterministic version-1 snapshot, optionally compressed with zlib.