Module traverse

Module traverse 

Filesystem traversal, in-memory tree representation, and traversal events.

Structs

BackgroundTraversal
An in-progress traversal which exposes newly obtained entries
Children
Iterator over a node’s children.
Entry
Borrowed view of an entry in a Tree.
EntryData
Metadata stored for a filesystem entry, excluding its arena-backed name.
Traversal
The result of the previous filesystem traversal
TraversalEntry
A filesystem entry waiting to be integrated into a traversal.
TraversalStats
Runtime statistics gathered while traversal is running.
Tree
Arena-backed filesystem tree with stable 32-bit node indices.
TreeIndex
Stable index of an entry in a Tree.

Enums

TraversalEvent
Events emitted by a background filesystem traversal.
TreeError
Failure to grow or modify a traversal tree.