Public library API for dua core traversal and aggregation functionality.
This crate powers the dua binary and can also be used as a library.
Modules
- snapshot
- Reading and writing dua traversal snapshots. Streaming codec for dua traversal snapshots.
- traverse
- Filesystem traversal, in-memory tree representation, and traversal events.
Structs
- Config
- Runtime configuration used by interactive and CLI components.
- Ignore
Patterns - Gitignore-style patterns, read from files, which exclude entries from a traversal.
- KeyBinding
- One key and its optional modifiers.
- KeyBindings
- One or more keys that invoke an interactive action.
- Keys
Config - Keyboard interaction settings.
- Traversal
Options - Platform-specific filesystem metadata requested during traversal.
- Walk
Options - Configures a filesystem walk, including output and formatting options.
- Walk
Result - Information we gather during a filesystem walk
Enums
- Byte
Format - Specifies a way to format bytes
Functions
- aggregate
- Aggregate the given
pathsand write information about them tooutin a human-readable format. Ifcompute_totalis set, it will write an additional line with the total size across all givenpaths. Ifsort_by_size_in_bytesis set, we will sort all sizes (ascending) before outputting them. - aggregate_
replay - Render the top-level entries of a verified snapshot replay as an aggregate listing.
- aggregate_
snapshot - Render the top-level entries of a verified traversal snapshot as an aggregate listing.
- aggregate_
tree - Traverse
pathsand write an indented tree of their disk usage toout, descending up tomax_depthlevels below each given root. - aggregate_
tree_ from_ replay - Replay a verified snapshot as an indented aggregate tree, retaining only displayed levels.
- aggregate_
tree_ from_ traversal - Write an already completed traversal as an indented aggregate tree.
- canonicalize_
ignore_ dirs - Canonicalize user-provided ignore directory paths.
- diff_
snapshots - Compare two verified traversal snapshots without materializing either tree.
- stacks
- Traverse
pathsand write the tree tooutas folded stacks, one entry per line, ready to pipe into flame-graph tools likeinferno. - stacks_
from_ replay - Replay a verified snapshot as folded stacks while retaining only the current path.
- stacks_
from_ traversal - Write an already completed traversal as folded stacks.