Crate dua

Crate dua 

Public library API for dua core traversal and aggregation functionality.

This crate powers the dua binary and can also be used as a library.

Modules

traverse
Filesystem traversal, in-memory tree representation, and traversal events.

Structs

Config
Runtime configuration used by interactive and CLI components.
IgnorePatterns
Gitignore-style patterns, read from files, which exclude entries from a traversal.
TraversalOptions
Platform-specific filesystem metadata requested during traversal.
WalkOptions
Configures a filesystem walk, including output and formatting options.
WalkResult
Information we gather during a filesystem walk

Enums

ByteFormat
Specifies a way to format bytes

Functions

aggregate
Aggregate the given paths and write information about them to out in a human-readable format. If compute_total is set, it will write an additional line with the total size across all given paths. If sort_by_size_in_bytes is set, we will sort all sizes (ascending) before outputting them.
aggregate_tree
Traverse paths and write an indented tree of their disk usage to out, descending up to max_depth levels below each given root.
canonicalize_ignore_dirs
Canonicalize user-provided ignore directory paths.
stacks
Traverse paths and write the tree to out as folded stacks, one entry per line, ready to pipe into flame-graph tools like inferno.