Public library API for dua core traversal and aggregation functionality.
This crate powers the dua binary and can also be used as a library.
Modules
- traverse
- Filesystem traversal, in-memory tree representation, and traversal events.
Structs
- Config
- Runtime configuration used by interactive and CLI components.
- Walk
- A single-root directory iterator whose directory reads happen in parallel.
Unlike
RootWalk, it yields entries directly and hides root identity and completion events. - Walk
Entry - A filesystem entry produced by
walk. - Walk
Options - Configures a filesystem walk, including output and formatting options.
- Walk
Result - Information we gather during a filesystem walk
Enums
- Byte
Format - Specifies a way to format bytes
- Walk
Order - Controls when entries are yielded relative to their descendants.
Functions
- aggregate
- Aggregate the given
pathsand write information about them tooutin a human-readable format. Ifcompute_totalis set, it will write an additional line with the total size across all givenpaths. Ifsort_by_size_in_bytesis set, we will sort all sizes (ascending) before outputting them. - canonicalize_
ignore_ dirs - Canonicalize user-provided ignore directory paths.
- walk
- Walk
rootwithout following symlinks. Unlikewalk_roots, this yields entries directly for a single root and hides completion events.