Filesystem traversal, in-memory tree representation, and traversal events.
Structs
- Background
Traversal - An in-progress traversal which exposes newly obtained entries
- Children
- Iterator over a node’s children.
- Entry
- Borrowed view of an entry in a
Tree. - Entry
Data - Metadata stored for a filesystem entry, excluding its arena-backed name.
- Traversal
- The result of the previous filesystem traversal
- Traversal
Entry - A filesystem entry waiting to be integrated into a traversal.
- Traversal
Stats - Runtime statistics gathered while traversal is running.
- Tree
- Arena-backed filesystem tree with stable 32-bit node indices.
- Tree
Index - Stable index of an entry in a
Tree.
Enums
- Traversal
Event - Events emitted by a background filesystem traversal.
- Tree
Error - Failure to grow or modify a traversal tree.