Module traverse

Module traverse 

Filesystem traversal, in-memory tree representation, and traversal events.

Structs

BackgroundTraversal
An in-progress traversal which exposes newly obtained entries
EntryData
Data stored for each filesystem entry in the traversal tree.
Traversal
The result of the previous filesystem traversal
TraversalStats
Runtime statistics gathered while traversal is running.

Enums

TraversalEvent
Events emitted by a background filesystem traversal.

Type Aliases

Tree
Graph type used to represent traversed filesystem entries.
TreeIndex
Node index type used by the traversal tree graph.