pub struct Tree { /* private fields */ }Expand description
Arena-backed filesystem tree with stable 32-bit node indices.
Implementations
Sourceimpl Tree
impl Tree
Sourcepub fn add_detached(
&mut self,
name: impl AsRef<Path>,
data: EntryData,
) -> TreeIndex
pub fn add_detached( &mut self, name: impl AsRef<Path>, data: EntryData, ) -> TreeIndex
Add a node that is not yet attached to the tree.
Sourcepub fn add_child(
&mut self,
parent: TreeIndex,
name: impl AsRef<Path>,
data: EntryData,
) -> TreeIndex
pub fn add_child( &mut self, parent: TreeIndex, name: impl AsRef<Path>, data: EntryData, ) -> TreeIndex
Add a child to parent, placing it before previously attached children.
Panics
Panics if parent is missing or the tree cannot grow.
Sourcepub fn try_add_root(
&mut self,
name: impl AsRef<Path>,
data: EntryData,
) -> Result<TreeIndex, TreeError>
pub fn try_add_root( &mut self, name: impl AsRef<Path>, data: EntryData, ) -> Result<TreeIndex, TreeError>
Try to add a parentless node.
Sourcepub fn try_add_child(
&mut self,
parent: TreeIndex,
name: impl AsRef<Path>,
data: EntryData,
) -> Result<TreeIndex, TreeError>
pub fn try_add_child( &mut self, parent: TreeIndex, name: impl AsRef<Path>, data: EntryData, ) -> Result<TreeIndex, TreeError>
Try to add a child to parent.
Sourcepub fn attach(
&mut self,
parent: TreeIndex,
child: TreeIndex,
) -> Result<(), TreeError>
pub fn attach( &mut self, parent: TreeIndex, child: TreeIndex, ) -> Result<(), TreeError>
Attach a parentless node to parent, before its existing children.
Sourcepub fn parent(&self, index: TreeIndex) -> Option<TreeIndex>
pub fn parent(&self, index: TreeIndex) -> Option<TreeIndex>
Return a node’s parent, or None for a parentless or missing node.
Sourcepub fn children(&self, index: TreeIndex) -> Children<'_> ⓘ
pub fn children(&self, index: TreeIndex) -> Children<'_> ⓘ
Iterate a node’s children in reverse insertion order.
Sourcepub fn indices(&self) -> impl Iterator<Item = TreeIndex> + '_
pub fn indices(&self) -> impl Iterator<Item = TreeIndex> + '_
Iterate all currently occupied node indices.
Sourcepub fn data(&self, index: TreeIndex) -> Option<EntryData>
pub fn data(&self, index: TreeIndex) -> Option<EntryData>
Return a copy of an entry’s metadata.
Sourcepub fn set_data(&mut self, index: TreeIndex, data: EntryData) -> bool
pub fn set_data(&mut self, index: TreeIndex, data: EntryData) -> bool
Replace an entry’s metadata, returning false if the index is missing.
Sourcepub fn update(
&mut self,
index: TreeIndex,
edit: impl FnOnce(&mut EntryData),
) -> bool
pub fn update( &mut self, index: TreeIndex, edit: impl FnOnce(&mut EntryData), ) -> bool
Mutate an entry’s metadata, returning false if the index is missing.
Sourcepub fn name(&self, index: TreeIndex) -> Option<Cow<'_, Path>>
pub fn name(&self, index: TreeIndex) -> Option<Cow<'_, Path>>
Return an entry’s arena-backed name.
Sourcepub fn rename(
&mut self,
index: TreeIndex,
name: impl AsRef<Path>,
) -> Result<(), TreeError>
pub fn rename( &mut self, index: TreeIndex, name: impl AsRef<Path>, ) -> Result<(), TreeError>
Replace an entry’s name. Old arena bytes remain reserved until the tree is dropped.
Sourcepub fn remove_subtree(&mut self, index: TreeIndex) -> usize
pub fn remove_subtree(&mut self, index: TreeIndex) -> usize
Remove index and all descendants, returning the number removed.